
unit VMCMain;

interface

uses
  Windows,
  Messages,
  SysUtils,
  Classes,
  Graphics,
  Controls,
  Forms,
  Dialogs,
  MDBEngine,
  StdCtrls;

type
  TVMCForm = class(TForm)
    GroupBox1: TGroupBox;
    Amount: TEdit;
    ExactChange: TCheckBox;
    Scaling: TEdit;
    Decimal: TEdit;
    Label1: TLabel;
    Label2: TLabel;
    Disable: TCheckBox;
    FreeVend: TCheckBox;
    Selection1: TButton;
    Selection2: TButton;
    Selection3: TButton;
    Selection4: TButton;
    VendSuccess: TButton;
    VendFailure: TButton;
    procedure WndProc(var Message: TMessage); override;
    procedure FormCreate(Sender: TObject);
    procedure FormDestroy(Sender: TObject);
    procedure DisableClick(Sender: TObject);
    procedure FreeVendClick(Sender: TObject);
    procedure FormShow(Sender: TObject);
    procedure Selection1Click(Sender: TObject);
    procedure Selection2Click(Sender: TObject);
    procedure Selection3Click(Sender: TObject);
    procedure Selection4Click(Sender: TObject);
    procedure VendSuccessClick(Sender: TObject);
    procedure VendFailureClick(Sender: TObject);
  private
    Procedure VMCDisplay;
    procedure VMCVend;
  public
    { Public-Deklarationen }
  end;

var
  g_VMCForm: TVMCForm;
  g_lAmount: longint;
  g_lScaling: longint;

implementation

{$R *.DFM}

procedure TVMCForm.FormCreate(Sender: TObject);

var
  Setup: VMC_SETUP;

begin
  g_lAmount:=0;
  g_lScaling:=0;
  Setup.lParam:=longint(@g_VMCForm);
  Setup.hParent:=g_VMCForm.handle;
  Setup.lDevice:=0;
  if not ExecutiveCreate(@Setup)
  then MessageDlg('Failed to create VMC.',mtWarning,[mbOk],0);
end;

procedure TVMCForm.FormDestroy(Sender: TObject);

begin
  if not ExecutiveDestroy()
  then MessageDlg('Failed to destroy VMC.',mtWarning,[mbOk],0);
end;

procedure TVMCForm.WndProc(var Message: TMessage);

begin
  if Message.Msg=WM_VMC_STATUS
  then begin
    case Message.wParam of
      SS_VMC_DISPLAY: VMCDisplay;
      SS_VMC_VEND: VMCVend;
    end;
  end else inherited WndProc(Message);
end;

procedure TVMCForm.VMCDisplay;

var
  Display: VMC_DISPLAY;

begin
  if ExecutiveGetDisplay(Display)
  then begin
    g_lAmount:=Display.lAmount;
    g_lScaling:=Display.lScaling;
    Amount.Text:=inttostr(Display.lAmount*Display.lScaling);
    Scaling.Text:=inttostr(Display.lScaling);
    Decimal.Text:=inttostr(Display.lDecimals);
    if Display.bExactChange
    then ExactChange.State:=cbChecked
    else ExactChange.State:=cbUnchecked;
    if Display.lAmount>0
    then begin
      Selection1.Enabled:=true;
      Selection2.Enabled:=true;
      Selection3.Enabled:=true;
      Selection4.Enabled:=true;
    end else begin
      Selection1.Enabled:=false;
      Selection2.Enabled:=false;
      Selection3.Enabled:=false;
      Selection4.Enabled:=false;
      VendSuccess.Enabled:=false;
      VendFailure.Enabled:=false;
    end;
  end;
end;

procedure TVMCForm.VMCVend;

begin
  if g_lAmount>0
  then begin
    VendSuccess.Enabled:=true;
    VendFailure.Enabled:=true;
  end;
end;

procedure TVMCForm.DisableClick(Sender: TObject);

var
  lStatus: longint;

begin
  lStatus:=0;
  if Disable.State=cbChecked
  then lStatus:=lStatus+EXE_INHIBIT;
  if FreeVend.State=cbChecked
  then lStatus:=lStatus+EXE_FREEVEND;
  ExecutiveControl(lStatus);
end;

procedure TVMCForm.FreeVendClick(Sender: TObject);

var
  lStatus: longint;

begin
  lStatus:=0;
  if Disable.State=cbChecked
  then lStatus:=lStatus+EXE_INHIBIT;
  if FreeVend.State=cbChecked
  then lStatus:=lStatus+EXE_FREEVEND;
  ExecutiveControl(lStatus);
end;

procedure TVMCForm.FormShow(Sender: TObject);

begin
  ExecutiveControl(0);
end;

procedure TVMCForm.Selection1Click(Sender: TObject);

begin
  ExecutivePrice((50 div g_lScaling) and $FF);
end;

procedure TVMCForm.Selection2Click(Sender: TObject);

begin
  ExecutivePrice((100 div g_lScaling) and $FF);
end;

procedure TVMCForm.Selection3Click(Sender: TObject);

begin
  ExecutivePrice((200 div g_lScaling) and $FF);
end;

procedure TVMCForm.Selection4Click(Sender: TObject);

begin
  ExecutivePrice((500 div g_lScaling) and $FF);
end;

procedure TVMCForm.VendSuccessClick(Sender: TObject);

begin
  ExecutiveVend(EXE_VENDSUCCESS);
end;

procedure TVMCForm.VendFailureClick(Sender: TObject);

begin
  ExecutiveVend(EXE_VENDFAILURE);
end;

end.

